;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'pc-select '("pc-select"))
(custom-add-loads 'keyboard '("pending-del"))
(custom-add-loads 'editing-options '("pc-select"))

;;; custom-load.el ends here
